@@ -127,44 +127,96 @@ test_that("eval_design_mc processes effectsize properly for glm", {
   expect_silent(
     res1 <- eval_design_mc(des, ~., glmfamily = 'gaussian', effectsize = 5,
                            alpha = 0.2, nsim = 1, detailedoutput = TRUE))
-  expect_equal(res1$anticoef, c(2.5, 2.5, 2.5), tolerance = 1e-8)
+  expect_equal(res1$anticoef, c(NA,NA,NA,2.5, 2.5, 2.5), tolerance = 1e-8)
 
   expect_warning(res2 <- eval_design_mc(des, ~., glmfamily = 'exponential', effectsize = 3,
                            alpha = 0.2, nsim = 1, detailedoutput = TRUE),
                "default or length 1 delta used with glmfamily == 'exponential'. This can lead to unrealistic effect sizes - make sure the generated anticipated coeffcients are appropriate.")
-  expect_equal(res2$anticoef, c(1.5, 1.5, 1.5))
+  expect_equal(res2$anticoef, c(NA,NA,NA,1.5, 1.5, 1.5))
 
   expect_warning(
     res3 <- eval_design_mc(des, ~., glmfamily = 'poisson', effectsize = 1,
                            alpha = 0.2, nsim = 1, detailedoutput = TRUE),
                "default or length 1 delta used with glmfamily == 'poisson'. This can lead to unrealistic effect sizes - make sure the generated anticipated coeffcients are appropriate.")
-  expect_equal(res3$anticoef, c(0.5, 0.5, 0.5))
+  expect_equal(res3$anticoef, c(NA,NA,NA,0.5, 0.5, 0.5))
 
   expect_warning(
     res4 <- eval_design_mc(des, ~., glmfamily = 'binomial', effectsize = 2,
                            alpha = 0.2, nsim = 1, detailedoutput = TRUE),
                "default or length 1 delta used with glmfamily == 'binomial'. This can lead to unrealistic effect sizes - make sure the generated anticipated coeffcients are appropriate")
-  expect_equal(res4$anticoef, c(1, 1, 1))
+  expect_equal(res4$anticoef, c(NA,NA,NA,1, 1, 1))
 
   #length = 2 effectsize, works in all cases:
   expect_silent(
     res5 <- eval_design_mc(des, ~., glmfamily = 'binomial', effectsize = c(0.6, 0.8),
                            alpha = 0.2, nsim = 1, detailedoutput = TRUE))
-  expect_equal(res5$anticoef, skpr:::gen_binomial_anticoef(c(1,1,1), 0.6, 0.8))
+  expect_equal(res5$anticoef, c(NA,NA,NA,skpr:::gen_binomial_anticoef(c(1,1,1), 0.6, 0.8)))
 
   expect_silent(
     res6 <- eval_design_mc(des, ~., glmfamily = 'exponential', effectsize = c(3, 5),
                            alpha = 0.2, nsim = 1, detailedoutput = TRUE))
-  expect_equal(res6$anticoef, skpr:::gen_exponential_anticoef(c(1,1,1), 3, 5))
+  expect_equal(res6$anticoef, c(NA,NA,NA,skpr:::gen_exponential_anticoef(c(1,1,1), 3, 5)))
 
   expect_silent(
     res7 <- eval_design_mc(des, ~., glmfamily = 'poisson', effectsize = c(5.2, 8.3),
                            alpha = 0.2, nsim = 1, detailedoutput = TRUE))
-  expect_equal(res7$anticoef, skpr:::gen_poisson_anticoef(c(1,1,1), 5.2, 8.3))
+  expect_equal(res7$anticoef, c(NA,NA,NA,skpr:::gen_poisson_anticoef(c(1,1,1), 5.2, 8.3)))
 
   expect_silent(
     res8 <- eval_design_mc(des, ~., glmfamily = 'gaussian', effectsize = c(5, 8),
                            alpha = 0.2, nsim = 1, detailedoutput = TRUE))
+  expect_equal(res8$anticoef, c(NA,NA,NA,1.5, 1.5, 1.5))
+
+})
+
+
+test_that("eval_design_mc processes effectsize properly for glm without effect power", {
+  set.seed(1)
+  cand = expand.grid(x = c(-1, 1), y = c(-1, 1))
+  des = gen_design(cand, ~., trials = 100)
+
+  #length = 1 effectsize, warning except for gaussian:
+  expect_silent(
+    res1 <- eval_design_mc(des, ~., glmfamily = 'gaussian', effectsize = 5,
+                           alpha = 0.2, nsim = 1, detailedoutput = TRUE,calceffect = FALSE))
+  expect_equal(res1$anticoef, c(2.5, 2.5, 2.5), tolerance = 1e-8)
+
+  expect_warning(res2 <- eval_design_mc(des, ~., glmfamily = 'exponential', effectsize = 3,
+                                        alpha = 0.2, nsim = 1, detailedoutput = TRUE,calceffect = FALSE),
+                 "default or length 1 delta used with glmfamily == 'exponential'. This can lead to unrealistic effect sizes - make sure the generated anticipated coeffcients are appropriate.")
+  expect_equal(res2$anticoef, c(1.5, 1.5, 1.5))
+
+  expect_warning(
+    res3 <- eval_design_mc(des, ~., glmfamily = 'poisson', effectsize = 1,
+                           alpha = 0.2, nsim = 1, detailedoutput = TRUE,calceffect = FALSE),
+    "default or length 1 delta used with glmfamily == 'poisson'. This can lead to unrealistic effect sizes - make sure the generated anticipated coeffcients are appropriate.")
+  expect_equal(res3$anticoef, c(0.5, 0.5, 0.5))
+
+  expect_warning(
+    res4 <- eval_design_mc(des, ~., glmfamily = 'binomial', effectsize = 2,
+                           alpha = 0.2, nsim = 1, detailedoutput = TRUE,calceffect = FALSE),
+    "default or length 1 delta used with glmfamily == 'binomial'. This can lead to unrealistic effect sizes - make sure the generated anticipated coeffcients are appropriate")
+  expect_equal(res4$anticoef, c(1, 1, 1))
+
+  #length = 2 effectsize, works in all cases:
+  expect_silent(
+    res5 <- eval_design_mc(des, ~., glmfamily = 'binomial', effectsize = c(0.6, 0.8),
+                           alpha = 0.2, nsim = 1, detailedoutput = TRUE,calceffect = FALSE))
+  expect_equal(res5$anticoef, skpr:::gen_binomial_anticoef(c(1,1,1), 0.6, 0.8))
+
+  expect_silent(
+    res6 <- eval_design_mc(des, ~., glmfamily = 'exponential', effectsize = c(3, 5),
+                           alpha = 0.2, nsim = 1, detailedoutput = TRUE,calceffect = FALSE))
+  expect_equal(res6$anticoef, skpr:::gen_exponential_anticoef(c(1,1,1), 3, 5))
+
+  expect_silent(
+    res7 <- eval_design_mc(des, ~., glmfamily = 'poisson', effectsize = c(5.2, 8.3),
+                           alpha = 0.2, nsim = 1, detailedoutput = TRUE,calceffect = FALSE))
+  expect_equal(res7$anticoef, skpr:::gen_poisson_anticoef(c(1,1,1), 5.2, 8.3))
+
+  expect_silent(
+    res8 <- eval_design_mc(des, ~., glmfamily = 'gaussian', effectsize = c(5, 8),
+                           alpha = 0.2, nsim = 1, detailedoutput = TRUE,calceffect = FALSE))
   expect_equal(res8$anticoef, c(1.5, 1.5, 1.5))
 
 })
